@@ -4,7 +4,7 @@ use crate::{MinMax,here};
 /// Reverse a generic slice by reverse iteration.
 /// Creates a new Vec. Its naive use for descending sort etc. 
 /// is to be avoided for efficiency reasons. 
-pub fn revs<T>(s: &[T]) -> Vec<T> where T: Copy, 
+pub fn revs<T>(s: &[T]) -> Vec<T> where T: Copy 
     { s.iter().rev().map(|&x| x).collect::<Vec<T>>() }
 
 /// Finds minimum, minimum's first index, maximum, maximum's first index 
